==> solac-library-0.0.19.tgz: package/src/hello-world-directive.js <==
'use strict';

angular.module('solac', [])
  .controller('HelloWorldController', function ($scope) {
    $scope.address = {
      name: 'Nadeen Southgate Address',
      address_line_1:'34 Kendle Crescent',
      address_line_2:'Newberg',
      postal_code:'7900',
      city: 'Cape Town',
      country: {
        name: 'SA'
      },
      created_at: '15/04/2016',
      contact_name: 'Nadeen Southgate',
      phone: '0756265898',
      fax: '0215896536',
      email: 'nadeen@acme.com'
    };
  })
  .directive("helloWorld", function () {
    return {
      restrict: "AE",
      controller: 'HelloWorldController',
      controllerAs: 'ctrl',
      template: `
      <div class="cs-panel cs-card" flex="100" flex-md="100" flex-sm="100" flex-xs="100">
        <div class="cs-panel-heading address-card-heading cs-card-heading" layout="row">
            <div flex="75" layout="row" layout-align="start center">
                <span><md-icon ng-if="address.head_office">business</md-icon><strong>{{address.name}}</strong></span>
            </div>
            <div flex="25" layout="row" layout-align="end center">
                <md-menu md-position-mode="target-right target" access="affiliateaddress.write">
                    <md-button class="md-icon-button" ng-click="$mdOpenMenu($event)">
                        <md-icon md-menu-origin>arrow_drop_down</md-icon>
                    </md-button>
                    <md-menu-content width="2">
                        <md-menu-item>
                            <md-button ng-click="onEditClick(null,address);">
                                <div layout="row">
                                    <p flex translate="Common.EDIT"></p>
                                </div>
                            </md-button>
                        </md-menu-item>
                        <md-menu-item>
                            <md-button ng-click="onRemoveClick(address);">
                                <div layout="row">
                                    <p flex translate="Common.REMOVE"></p>
                                </div>
                            </md-button>
                        </md-menu-item>
                    </md-menu-content>
                </md-menu>
            </div>
        </div>
        <div class="cs-panel-body address-card-body no-padding">
            <md-tabs md-align-tabs="top" md-border-bottom="false" md-stretch-tabs="always" md-dynamic-height>
                <md-tab label="Address">
                    <md-content class="address-card-padding">
                        <md-list>
                            <md-list-item class="md-2-line">
                                <md-icon class="card-icon-header">home</md-icon>
                                <div class="md-list-item-text" style="margin-top: 5px;">
                                    <h3 class="wrap-text">{{address.address_line_1}}, {{address.address_line_2}}</h3>
                                    <h3 class="wrap-text">{{address.postal_code}}, {{address.city}},</h3>
                                    <h3 class="wrap-text">{{address.country.name}}</h3>
                                </div>
                            </md-list-item>
                        </md-list>
                        <p class="address-footer-text no-margin-bottom" translate="Organisations.Addresses.ADDED_ON" translate-values="{date: address.created_at }">
                            </strong>
                        </p>
                    </md-content>
                </md-tab>
                <md-tab label="Contact">
                    <md-content class="address-card-padding">
                        <md-list>
                            <md-list-item class="md-2-line">
                                <md-icon>person</md-icon>
                                <div class="md-list-item-text">
                                    <h3 style="padding-top: 6px;">{{address.contact_name}}</h3>
                                </div>
                            </md-list-item>
                            <md-list-item class="md-2-line">
                                <md-icon>phone</md-icon>
                                <div class="md-list-item-text">
                                    <h3><span class="address-detail-label" translate="Organisations.Addresses.CARD.PHONE"></span>{{address.phone}}</h3>
                                    <h3><span class="address-detail-label" ng-if="address.fax" translate="Organisations.Addresses.CARD.FAX"></span><span ng-if="address.fax">{{address.fax}}</span></h3>
                                </div>
                            </md-list-item>
                            <md-list-item class="md-2-line">
                                <md-icon>email</md-icon>
                                <div class="md-list-item-text">
                                    <h3><a class="md-warn" ng-href="mailto:{{address.email}}">{{address.email}}</a></h3>
                                </div>
                            </md-list-item>
                        </md-list>
                    </md-content>
                </md-tab>
            </md-tabs>
        </div>
    </div>
      `
    };
  });

==> solac-library-0.0.20.tgz: package/src/hello-world-directive.js <==
'use strict';

angular.module('solac', [])
  .controller('HelloWorldController', function ($scope) {
    $scope.address = {
      name: 'Nadeen Southgate Address',
      address_line_1:'34 Kendle Crescent',
      address_line_2:'Newberg',
      postal_code:'7900',
      city: 'Cape Town',
      country: {
        name: 'SA'
      },
      created_at: '15/04/2016',
      contact_name: 'Nadeen Southgate',
      phone: '0756265898',
      fax: '0215896536',
      email: 'nadeen@acme.com'
    };
  })
  .directive("helloWorld", function () {
    return {
      restrict: "AE",
      controller: 'HelloWorldController',
      controllerAs: 'ctrl',
      template: `
      <div class="cs-panel cs-card" flex="100" flex-md="100" flex-sm="100" flex-xs="100">
        <div class="cs-panel-heading address-card-heading cs-card-heading" layout="row">
            <div flex="75" layout="row" layout-align="start center">
                <span><md-icon ng-if="address.head_office">business</md-icon><strong>{{address.name}}</strong></span>
            </div>
            <div flex="25" layout="row" layout-align="end center">
                <md-menu md-position-mode="target-right target">
                    <md-button class="md-icon-button" ng-click="$mdOpenMenu($event)">
                        <md-icon md-menu-origin>arrow_drop_down</md-icon>
                    </md-button>
                    <md-menu-content width="2">
                        <md-menu-item>
                            <md-button ng-click="onEditClick(null,address);">
                                <div layout="row">
                                    <p flex translate="Common.EDIT"></p>
                                </div>
                            </md-button>
                        </md-menu-item>
                        <md-menu-item>
                            <md-button ng-click="onRemoveClick(address);">
                                <div layout="row">
                                    <p flex translate="Common.REMOVE"></p>
                                </div>
                            </md-button>
                        </md-menu-item>
                    </md-menu-content>
                </md-menu>
            </div>
        </div>
        <div class="cs-panel-body address-card-body no-padding">
            <md-tabs md-align-tabs="top" md-border-bottom="false" md-stretch-tabs="always" md-dynamic-height>
                <md-tab label="Address">
                    <md-content class="address-card-padding">
                        <md-list>
                            <md-list-item class="md-2-line">
                                <md-icon class="card-icon-header">home</md-icon>
                                <div class="md-list-item-text" style="margin-top: 5px;">
                                    <h3 class="wrap-text">{{address.address_line_1}}, {{address.address_line_2}}</h3>
                                    <h3 class="wrap-text">{{address.postal_code}}, {{address.city}},</h3>
                                    <h3 class="wrap-text">{{address.country.name}}</h3>
                                </div>
                            </md-list-item>
                        </md-list>
                        <p class="address-footer-text no-margin-bottom" translate="Organisations.Addresses.ADDED_ON" translate-values="{date: address.created_at }">
                            </strong>
                        </p>
                    </md-content>
                </md-tab>
                <md-tab label="Contact">
                    <md-content class="address-card-padding">
                        <md-list>
                            <md-list-item class="md-2-line">
                                <md-icon>person</md-icon>
                                <div class="md-list-item-text">
                                    <h3 style="padding-top: 6px;">{{address.contact_name}}</h3>
                                </div>
                            </md-list-item>
                            <md-list-item class="md-2-line">
                                <md-icon>phone</md-icon>
                                <div class="md-list-item-text">
                                    <h3><span class="address-detail-label" translate="Organisations.Addresses.CARD.PHONE"></span>{{address.phone}}</h3>
                                    <h3><span class="address-detail-label" ng-if="address.fax" translate="Organisations.Addresses.CARD.FAX"></span><span ng-if="address.fax">{{address.fax}}</span></h3>
                                </div>
                            </md-list-item>
                            <md-list-item class="md-2-line">
                                <md-icon>email</md-icon>
                                <div class="md-list-item-text">
                                    <h3><a class="md-warn" ng-href="mailto:{{address.email}}">{{address.email}}</a></h3>
                                </div>
                            </md-list-item>
                        </md-list>
                    </md-content>
                </md-tab>
            </md-tabs>
        </div>
    </div>
      `
    };
  });
